<?php


/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 */

namespace Fullworks_Directory\Admin;



class Admin {

	/**
	 * The ID of this plugin.
	 *
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 */
	public function enqueue_styles() {

		/**
		 * @TODO decide if admin styles needed
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 */
	public function enqueue_scripts() {

		/**
		 * @TODO decide if admin scripts required.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/admin.js', array( 'jquery' ), $this->version, false );

	}

	public function register_metaboxes() {

	//@TODO open in new tab option

		$prefix = '_fd_entry_sub_title_';

		$cmb_sub_title = new_cmb2_box( array(
			'id'           => $prefix . 'sub_title',
			'title'        => esc_html__( 'Sub Title / Tag Line', 'fullworks-directory' ),
			'object_types' => array( 'fdentry' ), // Post type
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
		) );

		$cmb_sub_title->add_field( array(
			'name' => esc_html__( 'Sub Title', 'fullworks-directory' ),
			'desc' => esc_html__( 'A description or tag line under the entry title (optional)', 'fullworks-directory' ),
			'id'   => $prefix . 'sub_title',
			'type' => 'text',
		) );

		$prefix = '_fd_entry_info_block_';

		$cmb_cta = new_cmb2_box( array(
			'id'           => $prefix . 'info',
			'title'        => esc_html__( 'Directory Entry Information', 'fullworks-directory' ),
			'object_types' => array( 'fdentry' ), // Post type
			'priority'     => 'high',
			'show_names'   => true, // Show field names on the left
		) );

		$cmb_cta->add_field( array(
			'name' => esc_html__( 'Address', 'fullworks-directory' ),
			'desc' => esc_html__( 'Display address', 'fullworks-directory' ),
			'id'   => $prefix . 'address',
			'type' => 'text',
		) );
		$cmb_cta->add_field( array(
			'name' => esc_html__( 'Phone', 'fullworks-directory' ),
			'desc' => esc_html__( 'Contact phone number', 'fullworks-directory' ),
			'id'   => $prefix . 'phone',
			'type' => 'text',
		) );
		$cmb_cta->add_field( array(
			'name' => esc_html__( 'Email', 'fullworks-directory' ),
			'desc' => esc_html__( 'Email to display', 'fullworks-directory' ),
			'id'   => $prefix . 'email',
			'type' => 'text_email',
		) );

		$cmb_cta->add_field( array(
			'name' => esc_html__( 'Website', 'fullworks-directory' ),
			'desc' => esc_html__( 'URL', 'fullworks-directory' ),
			'id'   => $prefix . 'website',
			'type' => 'text_url',
		) );

	}



	/**
	 * Register the widget
	 */
	public function register_custom_widgets() {
		register_widget( 'Fullworks_Directory\Includes\Widgets\Entry_Info_Block_Widget' );
	}


}
