<?php


/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, hooks & filters
 *
 */

namespace Fullworks_Directory\FrontEnd;

use Fullworks_Directory\Includes\Template_Loader;

class FrontEnd {

	/**
	 * The ID of this plugin.
	 *
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 */
	private $version;

	private $post_id;

	/**
	 * Initialize the class and set its properties.
	 *
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;


	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 */
	public function enqueue_styles() {

		/**
		 * @TODO decide if front end style sheet needed
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/frontend.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 */
	public function enqueue_scripts() {

		/**
		 * @TODO decide if front end js required
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/frontend.js', array( 'jquery' ), $this->version, false );

	}

	/**
	 * Filter to decide on single templates
	 *
	 */
	public function single_template( $single_template ) {
		global $post;

		if ( $post->post_type == 'fdentry' ) {
			$template_loader = new Template_Loader;
			$single_template = $template_loader->locate_template( 'single-fdentry.php' );
		}

		return $single_template;


	}

	public function archive_template( $archive_template ) {
		global $post;

		if ( is_post_type_archive( 'fdentry' ) ) {
			$template_loader  = new Template_Loader;
			$archive_template = $template_loader->locate_template( 'archive-fdentry.php' );
		}

		return $archive_template;

	}

	public function taxonomy_template( $taxonomy_template ) {


		if ( is_tax( 'fd_entry_types' ) ) {
			$template_loader   = new Template_Loader;
			$taxonomy_template = $template_loader->locate_template( 'taxonomy-fd-entry-types.php' );
		}

		return $taxonomy_template;


	}


	public function entry_info_block_section() {
		global $post;
		$data            = array(
			'website'           => esc_url( get_post_meta( $post->ID, '_fd_entry_info_block_website', true ) ),
			'phone'     => esc_html( get_post_meta( $post->ID, '_fd_entry_info_block_phone', true ) ),
			'address'       => esc_html( get_post_meta( $post->ID, '_fd_entry_info_block_address', true ) ),
			'email' => esc_html( get_post_meta( $post->ID, '_fd_entry_info_block_email', true ) ),
			'post_name'      => $post->post_name,
		);
		$template_loader = new Template_Loader;
		$template_loader->set_template_data( $data );
		$template_loader->get_template_part( 'entry-info-block-section' );
	}




}
