<?php

/**
 *
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 *
 * Plugin Name:       Fullworks Directory
 * Plugin URI:        http://fullworks.net/wordpress-plugins/fullworks-directory/
 * Description:       Business or other entries Directory
 * Version:           1.0
 * Author:            Fullworks
 * Author URI:        http://fullworks.net/
 * License:           GPL-3.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       fullworks-directory
 * Domain Path:       /languages
 */

namespace Fullworks_Directory;

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}
if (!function_exists('Fullworks_Directory\run_fullworks_directory')) {
	define( 'FULLWORKS_DIRECTORY_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
	define( 'FULLWORKS_DIRECTORY_PLUGIN_VERSION', '1.0' );

// Include the autoloader so we can dynamically include the classes.
	require_once( FULLWORKS_DIRECTORY_PLUGIN_DIR . 'includes/autoloader.php' );


	/**
	 * Begins execution of the plugin.
	 *
	 * Since everything within the plugin is registered via hooks,
	 * then kicking off the plugin from this point in the file does
	 * not affect the page life cycle.
	 *
	 */
	function run_fullworks_directory() {
		/**
		 *  Load freemius SDK
		 */
		$freemius    = new \Fullworks_Directory\Includes\Freemius_Config();
		$freemius = $freemius->init();
		// Signal that SDK was initiated.
		do_action( 'fdir_fs_loaded' );

		/**
		 * The code that runs during plugin uninstall.
		 * This action is documented in includes/class-uninstall.php
		 * * use freemius hook
		 */

		$freemius->add_action( 'after_uninstall', array( '\Fullworks_Directory\Includes\Uninstall', 'uninstall' ) );


		/**
		 * The core plugin class that is used to define internationalization,
		 * admin-specific hooks, and public-facing site hooks.
		 */
		$plugin = new \Fullworks_Directory\Includes\Core( $freemius );
		$plugin->run();

	}

	run_fullworks_directory();
} else {
	die( __( 'Cannot execute as the plugin already exists, if you have a another version installed deactivate that and try again', 'fullworks-directory' ) );
}