<?php
/**
 * Created
 * User: alan
 * Date: 31/08/17
 * Time: 17:38
 */

namespace Fullworks_Directory\Includes;

use Fullworks_Directory\Includes\Shortcodes\PricingTable_Shortcode;


class Init {
	/**
	 * The ID of this plugin.
	 *
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 */
	private $version;

	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version     = $version;


	}

	public function custom_post_types() {
		register_post_type( 'fdentry',
			array(
				'labels'      => array(
					'name'          => __( 'Businesses', 'fullworks-directory' ),
					'singular_name' => __( 'Business' , 'fullworks-directory')
				),
				'public'      => true,
				'has_archive' => true,
				'show_in_rest' => true,
				'menu_icon'   => 'dashicons-groups',
				'rewrite'     => array( 'slug' => 'entry' ),
				'taxonomies'  => array( 'fd_entry_types' ),
			)
		);
		register_taxonomy(
			'fd_entry_types',  //The name of the taxonomy. Name should be in slug form (must not contain capital letters or spaces).
			'fdentry',        //post type name
			array(
				'labels'            => array(
					'name'          => 'Business Categories',
					'singular_name' => 'Business Category',
				),
				'hierarchical'      => true,
				'label'             => 'Business Category',  //Display name
				'query_var'         => true,
				'public'            => true,
				'show_in_rest' => true,
				'show_admin_column' => true,
				'rewrite'           => array( 'slug' => 'entry-type', 'hierachical' => true ),
				'show_ui'           => true,
			)
		);
		$post_type_support = array( 'editor', 'title', 'excerpt', 'comments','thumbnail', 'page-attributes', 'revisions','author' );
		// @TODO premium
		if ( function_exists( 'genesis_constants' ) ) {
			$post_type_support[] = 'genesis-cpt-archives-settings';
			$post_type_support[] = 'genesis-layouts';

		}
		add_post_type_support( 'fdentry', $post_type_support );

		add_image_size( 'fd-entry-featured-image', 680, 400, true );



	}

	public function widgets_init() {

		if ( function_exists( 'genesis_constants' ) ) {
			genesis_register_sidebar( array(
				'id'          => 'fd-entry-sidebar',
				'name'        => esc_html__( 'Directory Sidebar', 'fullworks-directory' ),
				'description' => esc_html__( 'Shown only on individual business pages', 'fullworks-directory' ),
			) );

		} else {
			register_sidebar( array(
				'name'          => esc_html__( 'Directory Sidebar', 'fullworks-directory' ),
				'id'            => 'fd-entry-sidebar',
				'description'   => esc_html__( 'Shown only on individual entry pages', 'fullworks-directory' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="widgettitle">',
				'after_title'   => '</h2>',
			) );
		}
	}




}