<?php
/**
 * content templates
 *
 * Created
 * User: alan
 * Date: 25/08/17
 * Time: 09:12
 */

namespace Fullworks_Directory\Includes;

use Gamajo_Template_Loader;


require_once dirname( __FILE__ ) . '/vendor/gamajo/template-loader/class-gamajo-template-loader.php';

/**
 * Template loader
 *
 * Only need to specify class properties here.
 *
 */
class Template_Loader extends Gamajo_Template_Loader {
	/**
	 * Prefix for filter names.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	protected $filter_prefix = 'fullworks-directory';

	/**
	 * Directory name where custom templates for this plugin should be found in the theme.
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	protected $theme_template_directory = 'fullworks-directory';

	/**
	 * Reference to the root directory path of this plugin.
	 *
	 * Can either be a defined constant, or a relative reference from where the subclass lives.
	 *
	 *
	 * @since 1.0.0
	 *
	 * @var string
	 */
	protected $plugin_directory = FULLWORKS_DIRECTORY_PLUGIN_DIR;

	/**
	 * Directory name where templates are found in this plugin.
	 *
	 * Can either be a defined constant, or a relative reference from where the subclass lives.
	 *
	 * e.g. 'templates' or 'includes/templates', etc.
	 *
	 * @since 1.1.0
	 *
	 * @var string
	 */
	protected $plugin_template_directory = 'templates';


	/**
	 * Retrieve the name of the highest priority template file that exists.
	 *
	 * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
	 * inherit from a parent theme can just overload one file. If the template is
	 * not found in either of those, it looks in the theme-compat folder last.
	 *
	 * @since 1.0.0
	 *
	 * @param string|array $template_names Template file(s) to search for, in order.
	 * @param bool $load If true the template file will be loaded if it is found.
	 * @param bool $require_once Whether to require_once or require. Default true.
	 *                                     Has no effect if $load is false.
	 *
	 * @return string The template filename if one is located.
	 *
	 *
	 *  Function overidden to apply logic to theme folders
	 */
	public function locate_template( $template_names, $load = false, $require_once = true ) {

		// Use $template_names as a cache key - either first element of array or the variable itself if it's a string
		$cache_key = is_array( $template_names ) ? $template_names[0] : $template_names;

		// If the key is in the cache array, we've already located this file.
		if ( isset( $this->template_path_cache[ $cache_key ] ) ) {
			$located = $this->template_path_cache[ $cache_key ];
		} else {

			// No file found yet.
			$located = false;

			// Remove empty entries.
			$template_names = array_filter( (array) $template_names );
			$template_paths = $this->get_template_paths();

			// Try to find a template file.
			foreach ( $template_names as $template_name ) {

				// added code to see if template a theme template
				$themetemplate=(( ( strncmp( $template_name, "single-", 7 ) === 0 ) ) ||
				     ( ( strncmp( $template_name, "archive-", 8 ) === 0 ) ) ||
				                ( ( strncmp( $template_name, "taxonomy-", 9 ) === 0 ) )
				)? true : false;

				// Trim off any slashes from the template name.
				$template_name = ltrim( $template_name, '/' );


				// added code to get the plugin dir for checking later
				$plugin_template_path = $this->get_templates_dir();

				// Try locating this template file by looping through the template paths.
				foreach ( $template_paths as $template_path ) {
					if (!$themetemplate) $template_path .= "content/";
					//@todo sort out hierrachy! dont think this works too well
						// landed in the plugin as path matches
					if ( trailingslashit($template_path) == trailingslashit($plugin_template_path)) {
						// if a theme template then extends the path depending on theme type
						if ( $themetemplate ) {
							$template_path .= "themes/";
							if ( function_exists( 'genesis_constants' ) ) {
								$template_path .= 'genesis/';
							} else {
								$template_path .= 'default/';
							}
						}
					}
					if ( file_exists( $template_path . $template_name ) ) {
						$located = $template_path . $template_name;
						// Store the template path in the cache
						$this->template_path_cache[ $cache_key ] = $located;
						break 2;
					}
				}
			}
		}

		if ( $load && $located ) {
			load_template( $located, $require_once );
		}

		return $located;
	}
}